///////////////////////////////////////////////////////////////////////////
//
// File: board.cc
//
// Purpose:
//
// Authors:
//   txe  Travis Emmitt
//
// Modifications:
//   14-APR-1998  txe  Initial Version
//   15-APR-1998  txe  Added Print(), SetDebug(), comments
//   20-APR-1998  txe  Purifying...
//   21-APR-1998  txe  Changed INDENT() call to BLANKS()
//   23-APR-1998  txe  Using static debug, changed constructor
//
///////////////////////////////////////////////////////////////////////////

#include <iostream.h>
#include <stdio.h>
#include <string.h>
#include "common.h"
#include "board.h"
#include "debug.h"

/////////////////////////////////////////////////////////////////////////////

Board::Board (char *name, int size_x, int size_y) : Debug (name) {
  ASSERT (name != NULL);
  ASSERT (size_x > 0 && size_x <= MAX_X);
  ASSERT (size_y > 0 && size_y <= MAX_Y);

  this->size_x = size_x;
  this->size_y = size_y;

  ITERATE (int, x, y, size_x, size_y) {
    colors[x][y] = EMPTY;
  }
}

/////////////////////////////////////////////////////////////////////////////

void Board::Copy (Board *b) {
  ASSERT (b != NULL);
  size_x = b->size_x;
  size_y = b->size_y;

  ITERATE (int, x, y, size_x, size_y) {
    colors[x][y] = b->colors[x][y];
  }
}

/////////////////////////////////////////////////////////////////////////////

int Board::GetColor (int x, int y) {
  ASSERT (x >= 0 && x < size_x);
  ASSERT (y >= 0 && y < size_y);
  return colors[x][y];
}

/////////////////////////////////////////////////////////////////////////////

int Board::GetMatch (int x, int y, Board *b) {
  ASSERT (x >= 0 && x < size_x);
  ASSERT (y >= 0 && y < size_y);
  ASSERT (b != NULL);

  int color = EMPTY, x1, y1;
  int size_x0 = b->GetSizeX ();
  int size_y0 = b->GetSizeY ();

  ITERATE (int, x0, y0, size_x0, size_y0) {
    if (b->colors[x0][y0] != EMPTY) {
      if ((x1 = x0 + x) >= size_x || (y1 = y0 + y) >= size_y) {
	return EMPTY;
      }
      if (color == EMPTY) {
	color = colors[x1][y1];
      }
      if (colors[x1][y1] == EMPTY || color != colors[x1][y1]) {
	return EMPTY;
      }
    }
  }
  return color;
}

/////////////////////////////////////////////////////////////////////////////

int Board::GetSizeX () {
  return size_x;
}

/////////////////////////////////////////////////////////////////////////////

int Board::GetSizeY () {
  return size_y;
}

/////////////////////////////////////////////////////////////////////////////

int Board::GetWinner (Board **win_boards) {
  ASSERT (win_boards != NULL);

  int winner = 0;

  ITERATE (int, x, y, size_x, size_y) {
    for (int i = 0; win_boards[i] != NULL; i++) {
      if ((winner = GetMatch (x, y, win_boards[i])) != EMPTY) {
	return winner;
      }
    }
  }
  return EMPTY;
}

////////////////////////////////////////////////////////////////////////////

int Board::MovesLeft () {
  int empties = 0;
  ITERATE (int, x, y, size_x, size_y) {
    empties += (colors[x][y] == EMPTY);
  }
  return empties;
}

////////////////////////////////////////////////////////////////////////////

void Board::Print () {
  ASSERT (name != NULL);
  int len = strlen (name) + 2, x, y;
  cout << "\n" << name << ": ";
  for (y = 0; y < size_y - 1; y++) {
    for (x = 0; x < size_x - 1; x++) {
      cout << colors[x][y] << "|";
    }
    cout << colors[x][y] << "\n" << BLANKS (len);
    for (x = 0; x < size_x-1; x++) {
      cout << "-+";
    }
    cout << "-\n" << BLANKS (len);
  }
  for (x = 0; x < size_x-1; x++) {
    cout << colors[x][y] << "|";
  }
  cout << colors[x][y] << "\n\n";
}

////////////////////////////////////////////////////////////////////////////

void Board::Print (int level) {
  if (debug >= level) {
    Print ();
  }
}

////////////////////////////////////////////////////////////////////////////

void Board::SetColor (int x, int y, int color) {
  ASSERT (x >= 0 && x < size_x);
  ASSERT (y >= 0 && y < size_y);
  colors[x][y] = color;
}

////////////////////////////////////////////////////////////////////////
