//////////////////////////////////////////////////////////////////////////////
//
// File: hplayer.h
//
// Purpose: This is the interface for the HumanPlayer class.  This provides
//          a game playing interface for a real-life person.  Humans have
//          their own  turn taking strategies, names, and sources of feedback!
//
// Authors:
//   txe  Travis Emmitt
//
// Modifications:
//   14-APR-1998  txe  Initial Version
//   15-APR-1998  txe  Added comments, LookForMatch(), GetBestMove()
//   16-APR-1998  txe  Added GetMove()
//   18-APR-1998  txe  Added PeekInto()
//   21-APR-1998  txe  Removed NewMatch()
//   23-APR-1998  txe  Added name to constrcutor
//   24-APR-1998  txe  Added NewGame(), NewMatch() overrides
//
//////////////////////////////////////////////////////////////////////////////

#ifndef HPLAYER_H
#define HPLAYER_H

#include "player.h"

class HumanPlayer : public Player {
  private:
  Referee *ref;                         // pointer to referee (player[0])
  void PeekInto  ();                    // peeks into opponent's brains
  void PrintHelp ();			// prints game-playing instructions
  
public:
  HumanPlayer (char *name, int color);
  void Feedback (int code);             // override, provides user feedback
  int  GetMove  ();                     // override, gets next move
  int  NewGame  ();                     // override, tells player new game
  int  NewMatch ();                     // override, tells player new match
};

#endif

//////////////////////////////////////////////////////////////////////////////
